@@ -19,6 +19,7 @@
     ENV <- object$orig.env
     ## tolerance options from model
     O <- object$options.tol
+    useN2 <- object$options.tol$useN2
     ## Doing CV?
     if(identical(CV, "none")) {
         want <- names(object$wa.optima) %in%
@@ -37,7 +38,7 @@
         if(identical(CV, "LOO")) {
             loo.pred <- matrix(0, ncol = n.train, nrow = n.fossil)
             mod.pred <- length(n.train)
-            useN2 <- object$options.tol$useN2
+            ##useN2 <- object$options.tol$useN2
             want <- names(object$wa.optima) %in% colnames(newdata)
             want <- names(object$wa.optima)[want]
             nr <- NROW(X) - 1
@@ -103,11 +104,11 @@
                 wa.optima <- w.avg(X[sel,,drop = FALSE], ENV[sel])
                 ## CV for the training set
                 if(object$tol.dw) {
-                    tol <- w.tol(X[sel, , drop = FALSE], ENV[-sel],
+                    tol <- w.tol(X[sel, , drop = FALSE], ENV[sel],
                                  wa.optima, useN2 = useN2)
                     ## fix up problematic tolerances
                     tol <- fixUpTol(tol, O$na.tol, O$small.tol,
-                                    O$min.tol, O$f, ENV[-sel])
+                                    O$min.tol, O$f, ENV[sel])
                     wa.env <- WATpred(X[sel, , drop = FALSE],
                                       wa.optima, tol, nr, nc)
                     pred <- WATpred(X[-sel, ,drop=FALSE], wa.optima,
@@ -154,11 +155,11 @@
                     wa.optima <- w.avg(X[sel,], ENV[sel])
                     ## CV for the training set
                     if(object$tol.dw) {
-                        tol <- w.tol(X[sel, , drop = FALSE], ENV[-sel],
+                        tol <- w.tol(X[sel, , drop = FALSE], ENV[sel],
                                      wa.optima, useN2 = useN2)
                         ## fix up problematic tolerances
                         tol <- fixUpTol(tol, O$na.tol, O$small.tol,
-                                        O$min.tol, O$f, ENV[-sel])
+                                        O$min.tol, O$f, ENV[sel])
                         wa.env <- WATpred(X[sel, , drop = FALSE],
                                           wa.optima, tol, nr, nc)
                         pred <- WATpred(X[-sel, ,drop=FALSE], wa.optima,
@@ -218,7 +219,7 @@
         retval$model.pred <- list(pred = fitted(object))
     } else if(identical(CV, "LOO")) {
         mod.r.squared <- cor(mod.pred, ENV)^2
-        mod.resid <- mod.pred - ENV
+        mod.resid <- ENV - mod.pred ##mod.pred - ENV
         mod.avg.bias <- mean(mod.resid)
         mod.max.bias <- maxBias(mod.resid, ENV)
         mod.rmsep <- sqrt(mean(mod.resid^2))
@@ -231,9 +232,10 @@
                                   resid = mod.resid)
     } else {
         mod.pred <- rowMeans(oob.pred, na.rm = TRUE)
-        mod.resid <- mod.pred - ENV
+        mod.resid <- ENV - mod.pred ##mod.pred - ENV
         s1 <- apply(oob.pred, 1, sd, na.rm = TRUE)
-        s2 <- sqrt(rowMeans((oob.pred - ENV)^2, na.rm = TRUE))
+        ##s2 <- sqrt(rowMeans((oob.pred - ENV)^2, na.rm = TRUE))
+        s2 <- sqrt(rowMeans((ENV - oob.pred)^2, na.rm = TRUE))
         mod.s1 <- sqrt(mean(s1^2))
         mod.s2 <- sqrt(mean(mod.resid^2))
         samp.rmsep <- sqrt(s1^2 + mod.s2^2)
