@@ -1,5 +1,5 @@
 .First.lib <- function(lib, pkg)  {
-    ##library.dynam("analogue", pkg, lib)
+    library.dynam("analogue", pkg, lib)
     packageStartupMessage("This is analogue ",
                           utils::packageDescription("analogue",
                                                     field="Version"),
